from dungeonbattle.menus import Menu, MainMenu
from typing import Any
from .display import Display
import curses

class MenuDisplay(Display):
    position: int
    
    def __init__(self, *args) :
        super().__init__(*args)
        self.menubox = self.newpad(self.height,self.width)

    def update_menu(self, menu: Menu):
        self.menu = menu
        self.values = menu.values
        self.trueheight = len(menu.values)
        self.truewidth = max(map(len,self.values))

        #Menu values are printed in pad
        self.pad = self.newpad(self.trueheight,self.truewidth+1)
        for i in range(self.trueheight-1) :
            self.pad.addstr(i,0," " + self.values[i])
        

    def update_pad(self) -> None:
        for i in range(self.trueheight) :
            self.pad.addstr(i,0," ")
        self.pad.addstr(self.menu.position,0,">") #set a marker on the selected line

    def display(self) -> None:
        if self.height-2>=self.menu.position-1 :
            cornery = 0
        elif self.height-2 >= self.trueheight-self.menu.position :
            cornery = self.trueheight-self.height+2
            

        #Menu box
        self.menubox.addstr(0,0,"┏"+"━"*(self.width-2)+"┓")
        for i in range(1,self.height-2) :
            self.menubox.addstr(i,0,"┃"+" "*(self.width-2)+"┃")
        self.menubox.addstr(self.height-2, 0, "┗"+"━"*(self.width-2)+"┛")
        
        self.menubox.refresh(0, 0, self.y, self.x,
                          self.height + self.y,
                         self.width + self.x)
        self.update_pad()
        self.pad.refresh(cornery, 0, self.y+1, self.x+1,
                          self.height-2 + self.y,
                         self.width-2 + self.x)

class MainMenuDisplay(Display):
    def __init__(self, menu : MainMenu, *args) :
        super().__init__(*args)
        self.menu = menu
        self.pad = self.newpad(self.rows, self.cols)

        with open("ascii_art.txt", "r") as file:
            self.title = file.read().split("\n")

        self.menudisplay = MenuDisplay(self.screen)
        self.menudisplay.update_menu(self.menu)
        
    def dislpay(self) -> None:
        for i in range(len(self.title)) :
            self.pad.addstr(4+i,self.width//2-len(self.title[0])//2-1,self.title[i])
        self.pad.refresh(0,0,self.y,self.x,self.width,self.height)
        menuy, menux = len(self.title)+8, self.width//2-15//2-1
        self.menudisplay.refresh(menuy, menux, min(15, self.rows-menuy), min(15,self.cols-menux))
        
        
